@@ -13,13 +13,15 @@
 #include <ostream>
 #include <string>
 
+#include "odil/odil.h"
+
 namespace odil
 {
 
 /**
  * @brief A DICOM element tag.
  */
-class Tag
+class ODIL_API Tag
 {
 public:
     /// @brief Create a tag based on its group and element as two 16-bits words.
@@ -48,6 +50,16 @@ public:
      */
     Tag(char const * string);
 
+    /** @addtogroup default_operations Default class operations
+     * @{
+     */
+    ~Tag() =default;
+    Tag(Tag const &) =default;
+    Tag(Tag &&) =default;
+    Tag & operator=(Tag const &) =default;
+    Tag & operator=(Tag &&) =default;
+    /// @}
+
     /// @brief Group of the tag.
     uint16_t group;
 
@@ -91,7 +103,7 @@ private:
 };
 
 /// @brief Stream inserter
-std::ostream & operator<<(std::ostream & stream, Tag const & tag);
+ODIL_API std::ostream & operator<<(std::ostream & stream, Tag const & tag);
 
 }
 
