@@ -20,11 +20,11 @@ namespace odil
 
 /// @brief Convert a data set to its JSON representation.
 ODIL_API Json::Value as_json(
-    DataSet const & data_set,
-    odil::Value::Strings const & specific_character_set=odil::Value::Strings());
+    std::shared_ptr<DataSet const> data_set,
+    Value::Strings const & specific_character_set={});
 
 /// @brief Create a data set from its JSON representation.
-ODIL_API DataSet as_dataset(Json::Value const & json);
+ODIL_API std::shared_ptr<DataSet> as_dataset(Json::Value const & json);
 
 }
 
