@@ -9,6 +9,7 @@
 #ifndef _3980566c_9185_40a2_8e7d_6286c2cd1959
 #define _3980566c_9185_40a2_8e7d_6286c2cd1959
 
+#include "odil/odil.h"
 #include "odil/pdu/Object.h"
 
 namespace odil
@@ -18,7 +19,7 @@ namespace pdu
 {
 
 /// @brief A-ASSOCIATE-RJ PDU, cf. PS 3.8, 9.3.4.
-class AAssociateRJ: public Object
+class ODIL_API AAssociateRJ: public Object
 {
 public:
     /// @brief Constructor.
