@@ -30,7 +30,9 @@ Tag const InstanceCreationTime(0x0008, 0x0013);
 Tag const InstanceCreatorUID(0x0008, 0x0014);
 Tag const InstanceCoercionDateTime(0x0008, 0x0015);
 Tag const SOPClassUID(0x0008, 0x0016);
+Tag const AcquisitionUID(0x0008, 0x0017);
 Tag const SOPInstanceUID(0x0008, 0x0018);
+Tag const PyramidUID(0x0008, 0x0019);
 Tag const RelatedGeneralSOPClassUID(0x0008, 0x001a);
 Tag const OriginalSpecializedSOPClassUID(0x0008, 0x001b);
 Tag const StudyDate(0x0008, 0x0020);
@@ -141,6 +143,7 @@ Tag const OperatorsName(0x0008, 0x1070);
 Tag const OperatorIdentificationSequence(0x0008, 0x1072);
 Tag const AdmittingDiagnosesDescription(0x0008, 0x1080);
 Tag const AdmittingDiagnosesCodeSequence(0x0008, 0x1084);
+Tag const PyramidDescription(0x0008, 0x1088);
 Tag const ManufacturerModelName(0x0008, 0x1090);
 Tag const ReferencedResultsSequence(0x0008, 0x1100);
 Tag const ReferencedStudySequence(0x0008, 0x1110);
