@@ -191,9 +191,28 @@ Tag const CompressionForce(0x0018, 0x11a2);
 Tag const CompressionPressure(0x0018, 0x11a3);
 Tag const PaddleDescription(0x0018, 0x11a4);
 Tag const CompressionContactArea(0x0018, 0x11a5);
+Tag const AcquisitionMode(0x0018, 0x11b0);
+Tag const DoseModeName(0x0018, 0x11b1);
+Tag const AcquiredSubtractionMaskFlag(0x0018, 0x11b2);
+Tag const FluoroscopyPersistenceFlag(0x0018, 0x11b3);
+Tag const FluoroscopyLastImageHoldPersistenceFlag(0x0018, 0x11b4);
+Tag const UpperLimitNumberOfPersistentFluoroscopyFrames(0x0018, 0x11b5);
+Tag const ContrastBolusAutoInjectionTriggerFlag(0x0018, 0x11b6);
+Tag const ContrastBolusInjectionDelay(0x0018, 0x11b7);
+Tag const XAAcquisitionPhaseDetailsSequence(0x0018, 0x11b8);
+Tag const XAAcquisitionFrameRate(0x0018, 0x11b9);
+Tag const XAPlaneDetailsSequence(0x0018, 0x11ba);
+Tag const AcquisitionFieldOfViewLabel(0x0018, 0x11bb);
+Tag const XRayFilterDetailsSequence(0x0018, 0x11bc);
+Tag const XAAcquisitionDuration(0x0018, 0x11bd);
+Tag const ReconstructionPipelineType(0x0018, 0x11be);
+Tag const ImageFilterDetailsSequence(0x0018, 0x11bf);
+Tag const AppliedMaskSubtractionFlag(0x0018, 0x11c0);
+Tag const RequestedSeriesDescriptionCodeSequence(0x0018, 0x11c1);
 Tag const DateOfLastCalibration(0x0018, 0x1200);
 Tag const TimeOfLastCalibration(0x0018, 0x1201);
 Tag const DateTimeOfLastCalibration(0x0018, 0x1202);
+Tag const CalibrationDateTime(0x0018, 0x1203);
 Tag const ConvolutionKernel(0x0018, 0x1210);
 Tag const UpperLowerPixelValues(0x0018, 0x1240);
 Tag const ActualFrameDuration(0x0018, 0x1242);
@@ -360,6 +379,7 @@ Tag const NumberOfTableEntries(0x0018, 0x6056);
 Tag const TableOfPixelValues(0x0018, 0x6058);
 Tag const TableOfParameterValues(0x0018, 0x605a);
 Tag const RWaveTimeVector(0x0018, 0x6060);
+Tag const ActiveImageAreaOverlayGroup(0x0018, 0x6070);
 Tag const DetectorConditionsNominalFlag(0x0018, 0x7000);
 Tag const DetectorTemperature(0x0018, 0x7001);
 Tag const DetectorType(0x0018, 0x7004);
