@@ -294,6 +294,7 @@ Tag const SourceApplicatorManufacturer(0x300a, 0x0298);
 Tag const SourceApplicatorWallNominalThickness(0x300a, 0x029c);
 Tag const SourceApplicatorWallNominalTransmission(0x300a, 0x029e);
 Tag const SourceApplicatorStepSize(0x300a, 0x02a0);
+Tag const ApplicatorShapeReferencedROINumber(0x300a, 0x02a1);
 Tag const TransferTubeNumber(0x300a, 0x02a2);
 Tag const TransferTubeLength(0x300a, 0x02a4);
 Tag const ChannelShieldSequence(0x300a, 0x02b0);
@@ -601,6 +602,33 @@ Tag const ReferencedExpectedInVivoMeasurementValueIndex(0x300a, 0x0773);
 Tag const DoseMeasurementDeviceCodeSequence(0x300a, 0x0774);
 Tag const AdditionalParameterRecordingInstanceSequence(0x300a, 0x0780);
 Tag const InterlockOriginDescription(0x300a, 0x0783);
+Tag const RTPatientPositionScopeSequence(0x300a, 0x0784);
+Tag const ReferencedTreatmentPositionGroupUID(0x300a, 0x0785);
+Tag const RadiationOrderIndex(0x300a, 0x0786);
+Tag const OmittedRadiationSequence(0x300a, 0x0787);
+Tag const ReasonForOmissionCodeSequence(0x300a, 0x0788);
+Tag const RTDeliveryStartPatientPositionSequence(0x300a, 0x0789);
+Tag const RTTreatmentPreparationPatientPositionSequence(0x300a, 0x078a);
+Tag const ReferencedRTTreatmentPreparationSequence(0x300a, 0x078b);
+Tag const ReferencedPatientSetupPhotoSequence(0x300a, 0x078c);
+Tag const PatientTreatmentPreparationMethodCodeSequence(0x300a, 0x078d);
+Tag const PatientTreatmentPreparationProcedureParameterDescription(0x300a, 0x078e);
+Tag const PatientTreatmentPreparationDeviceSequence(0x300a, 0x078f);
+Tag const PatientTreatmentPreparationProcedureSequence(0x300a, 0x0790);
+Tag const PatientTreatmentPreparationProcedureCodeSequence(0x300a, 0x0791);
+Tag const PatientTreatmentPreparationMethodDescription(0x300a, 0x0792);
+Tag const PatientTreatmentPreparationProcedureParameterSequence(0x300a, 0x0793);
+Tag const PatientSetupPhotoDescription(0x300a, 0x0794);
+Tag const PatientTreatmentPreparationProcedureIndex(0x300a, 0x0795);
+Tag const ReferencedPatientSetupProcedureIndex(0x300a, 0x0796);
+Tag const RTRadiationTaskSequence(0x300a, 0x0797);
+Tag const RTPatientPositionDisplacementSequence(0x300a, 0x0798);
+Tag const RTPatientPositionSequence(0x300a, 0x0799);
+Tag const DisplacementReferenceLabel(0x300a, 0x079a);
+Tag const DisplacementMatrix(0x300a, 0x079b);
+Tag const PatientSupportDisplacementSequence(0x300a, 0x079c);
+Tag const DisplacementReferenceLocationCodeSequence(0x300a, 0x079d);
+Tag const RTRadiationSetDeliveryUsage(0x300a, 0x079e);
 
 }
 
