@@ -26,6 +26,7 @@
 #include "odil/DataSet.h"
 #include "odil/json_converter.h"
 #include "odil/Reader.h"
+#include "odil/StringStream.h"
 #include "odil/VRFinder.h"
 #include "odil/Writer.h"
 #include "odil/webservices/ItemWithParameters.h"
@@ -35,7 +36,6 @@
 #include "odil/webservices/URL.h"
 #include "odil/xml_converter.h"
 
-
 namespace  odil
 {
 
@@ -44,8 +44,8 @@ namespace webservices
 
 STOWRSRequest
 ::STOWRSRequest(URL const & base_url)
-    : _base_url(base_url), _transfer_syntax(""), _selector(), _url(),
-      _media_type(""), _representation(), _data_sets()
+: _base_url(base_url), _transfer_syntax(""), _selector(), _url(),
+  _media_type(""), _representation(), _data_sets()
 {
     // Nothing else.
 }
@@ -54,74 +54,56 @@ STOWRSRequest
 ::STOWRSRequest(HTTPRequest const & request)
 {
     this->_url = request.get_target();
-    if (request.has_header("Host"))
+    if(request.has_header("Host"))
     {
         this->_url.authority = request.get_header("Host");
     }
 
-    // find the media type in Content-Type header
-    if (!request.has_header("Content-Type"))
-    {
-        throw Exception("Cannot parse request : Content-Type header is missing");
-    }
-    auto const header_content_type = boost::lexical_cast<ItemWithParameters>(
+    auto const content_type = as<ItemWithParameters>(
         request.get_header("Content-Type"));
-    if (header_content_type.name == "multipart/related")
+    if(content_type.name == "multipart/related")
     {
-        auto const it = header_content_type.name_parameters.find("type");
-        if(it == header_content_type.name_parameters.end())
-        {
-            std::ostringstream message;
-            message << "Missing type is Accept header :"
-                    << request.get_header("Accept");
-            throw Exception(message.str());
-        }
-        this->_media_type = it->second;
+        this->_media_type = content_type.name_parameters.at("type");
     }
     else
     {
         throw Exception("Malformed Content-Type header");
     }
 
-    if (this->_media_type == "application/dicom")
+    if(this->_media_type == "application/dicom")
     {
         this->_representation = Representation::DICOM;
-        auto const converter =
+
+        transform_parts(
+            request, std::back_inserter(this->get_data_sets()),
             [](Message const & part)
             {
-                std::stringstream stream(part.get_body());
-                Reader reader(stream, odil::registry::ExplicitVRLittleEndian);
+                IStringStream stream(
+                    &part.get_body()[0], part.get_body().size());
+                Reader reader(stream, registry::ExplicitVRLittleEndian);
                 auto const ds = reader.read_file(stream);
                 return ds.second;
-            };
-        transform_parts(
-            request, std::back_inserter(this->get_data_sets()), converter);
+            });
     }
-    else if (this->_media_type == "application/dicom+xml")
+    else if(this->_media_type == "application/dicom+xml")
     {
         this->_representation = Representation::DICOM_XML;
-        std::map< std::string, std::string> uuid_to_bulk_raw;
 
-        auto converter_part =
-            [&uuid_to_bulk_raw, this](Message const & part)
+        // Get data sets and bulk data from parts
+        BulkMap bulk_map;
+        for_each_part(
+            request,
+            [&bulk_map, this](Message const & part)
             {
-                auto const header_content_type = boost::lexical_cast<ItemWithParameters>(
+                auto const content_type = as<ItemWithParameters>(
                     part.get_header("Content-Type"));
-                if (header_content_type.name == "application/dicom+xml")
+                if(content_type.name == "application/dicom+xml")
                 {
-                    // get the transfer syntax in the ContentType header
-                    auto const transfer_syntax_it = header_content_type.name_parameters.find(
+                    this->_transfer_syntax = content_type.name_parameters.at(
                         "transfer-syntax");
-                    if(transfer_syntax_it != header_content_type.name_parameters.end())
-                    {
-                        this->_transfer_syntax = transfer_syntax_it->second;
-                    }
-                    else
-                    {
-                        throw Exception("Transfer-syntax option is missing in the header");
-                    }
-                    // Check here if correct probably ok
-                    std::stringstream stream(part.get_body());
+
+                    IStringStream stream(
+                        &part.get_body()[0], part.get_body().size());
                     boost::property_tree::ptree xml;
                     boost::property_tree::read_xml(stream, xml);
                     this->get_data_sets().push_back(as_dataset(xml));
@@ -129,49 +111,45 @@ STOWRSRequest
                 else
                 {
                     auto const location = part.get_header("Content-Location");
-                    uuid_to_bulk_raw.insert(std::make_pair(location, part.get_body()));
+                    Value::Binary::value_type const data(
+                        part.get_body().begin(), part.get_body().end());
+                    bulk_map.insert({location, data});
                 }
-            };
+            });
 
-        for_each_part(request, converter_part);
-
-        // Here restore dataSets to their initial states (With Bulk Data in the correct location)
-        for (auto & data_set : this->get_data_sets())
+        // Restore bulk data items to data sets
+        for(auto & data_set : this->get_data_sets())
         {
-            STOWRSRequest::_restore_data_set(data_set, uuid_to_bulk_raw);
+            STOWRSRequest::_restore_data_set(data_set, bulk_map);
         }
     }
     else if (this->_media_type == "application/dicom+json")
     {
         this->_representation = Representation::DICOM_JSON;
-        std::map< std::string, std::string> uuid_to_bulk_raw;
 
-        auto converter_part =
-            [&uuid_to_bulk_raw, this](Message const & part)
+        // Get data sets and bulk data from parts
+        BulkMap bulk_map;
+        for_each_part(
+            request,
+            [&bulk_map, this](Message const & part)
             {
-                auto const header_content_type = boost::lexical_cast<ItemWithParameters>(
+                auto const content_type = as<ItemWithParameters>(
                     part.get_header("Content-Type"));
-                if (header_content_type.name == "application/dicom+json")
+                if(content_type.name == "application/dicom+json")
                 {
-                    // get the transfer syntax in the ContentType header
-                    auto const transfer_syntax_it = header_content_type.name_parameters.find(
+                    this->_transfer_syntax = content_type.name_parameters.at(
                         "transfer-syntax");
-                    if(transfer_syntax_it != header_content_type.name_parameters.end())
-                    {
-                        this->_transfer_syntax = transfer_syntax_it->second;
-                    }
-                    else
-                    {
-                        throw Exception("Transfer-syntax option is missing in the header");
-                    }
-                    std::stringstream stream(part.get_body());
+
+                    IStringStream stream(
+                        &part.get_body()[0], part.get_body().size());
                     Json::Value array;
                     stream >> array;
                     if(!array.isArray())
                     {
                         throw Exception("Body must be an array");
                     }
-                    for (auto const json : array)
+
+                    for(auto const & json: array)
                     {
                         this->get_data_sets().push_back(as_dataset(json));
                     }
@@ -179,23 +157,31 @@ STOWRSRequest
                 else
                 {
                     auto const location = part.get_header("Content-Location");
-                    uuid_to_bulk_raw.insert(std::make_pair(location, part.get_body()));
+                    Value::Binary::value_type const data{
+                        part.get_body().begin(), part.get_body().end()};
+                    bulk_map.insert({location, data});
                 }
-            };
-        for_each_part(request, converter_part);
+            });
 
-        // Here restore dataSets to their initial state (With Bulk Data in the correct location)
-        for (auto & data_set : this->get_data_sets())
+        // Restore bulk data items to data sets
+        for(auto & data_set: this->get_data_sets())
         {
-            STOWRSRequest::_restore_data_set(data_set, uuid_to_bulk_raw);
+            STOWRSRequest::_restore_data_set(data_set, bulk_map);
         }
     }
     else
     {
-        throw Exception("Unknown media type" + this->_media_type);
+        throw Exception("Unknown media type: " + this->_media_type);
+    }
+
+    this->_base_url.scheme = request.get_target().scheme;
+    this->_base_url.authority = request.get_target().authority;
+    std::tie(this->_base_url.path, this->_selector) = Selector::from_path(
+        request.get_target().path);
+    if(!STOWRSRequest::_is_selector_valid(this->_selector))
+    {
+        throw Exception("Invalid selector");
     }
-    std::tie(this->_base_url, this->_selector) =
-            STOWRSRequest::_split_full_url(this->_url);
 }
 
 bool
@@ -219,102 +205,63 @@ STOWRSRequest
     return !(*this == other);
 }
 
-std::pair<URL, Selector>
-STOWRSRequest
-::_split_full_url(URL const &url)
-{
-    URL base_url;
-
-    std::string study;
-    auto const position = url.path.rfind("/studies");
-
-    if (position != std::string::npos)
-    {
-        base_url = {
-            url.scheme, url.authority, url.path.substr(0, position), "", "" };
-        auto const resource = url.path.substr(position+1);
-
-        typedef std::string::const_iterator Iterator;
-
-        namespace qi = boost::spirit::qi;
-        namespace p = boost::phoenix;
-
-        using boost::spirit::qi::char_;
-        using boost::spirit::qi::lit;
-        using boost::spirit::qi::string;
-        using boost::spirit::qi::_1;
-
-        qi::rule<Iterator, std::string()> value = +(~char_("/"));
-
-        qi::rule<Iterator> retrieve_study =
-            lit("studies/") >> value[p::ref(study) = _1];
-
-        auto iterator = resource.begin();
-        qi::phrase_parse(
-            iterator, resource.end(),
-            retrieve_study,
-            boost::spirit::qi::ascii::space
-        );
-    }
-
-    Selector selector({{"studies", study}});
-
-    return std::make_pair(base_url, selector);
-}
-
 bool
 STOWRSRequest
 ::_is_selector_valid(Selector const & selector)
 {
-    return (selector.is_study_present() && !selector.is_series_present()
-            && !selector.is_instance_present() && selector.get_frames().empty());
+    return (
+        selector.is_study_present() && !selector.is_series_present()
+        && !selector.is_instance_present() && selector.get_frames().empty());
 }
 
 void
 STOWRSRequest
-::request_dicom(std::vector<DataSet> const & data_sets, Selector const & selector,
-                Representation const & representation, std::string const & transfer_syntax)
+::request_dicom(
+    Value::DataSets const & data_sets, Selector const & selector,
+    Representation const & representation, std::string const & transfer_syntax)
 {
-    switch (representation)
+    this->_representation = representation;
+
+    if(representation == Representation::DICOM)
     {
-    case Representation::DICOM :
-        this->_representation = Representation::DICOM;
         this->_media_type = "application/dicom";
-        break;
-    case Representation::DICOM_XML :
-        this->_representation = Representation::DICOM_XML;
+    }
+    else if(representation == Representation::DICOM_XML)
+    {
         this->_media_type = "application/dicom+xml";
         this->_transfer_syntax = transfer_syntax;
-        break;
-    case Representation::DICOM_JSON :
-        this->_representation = Representation::DICOM_JSON;
+    }
+    else if(representation == Representation::DICOM_JSON)
+    {
         this->_media_type = "application/dicom+json";
         this->_transfer_syntax = transfer_syntax;
-        break;
-    default :
+    }
+    else
+    {
         throw Exception("Invalid representation");
-        break;
     }
 
     this->_data_sets = data_sets;
-    if (!_is_selector_valid(selector))
+
+    if(!STOWRSRequest::_is_selector_valid(selector))
     {
-        throw Exception("Selector is not valid (" + selector.get_path(false) + ")");
+        throw Exception("Invalid selector");
     }
     this->_selector = selector;
+
     auto path = this->_base_url.path + selector.get_path(false);
     this->_url = {
         this->_base_url.scheme, this->_base_url.authority, path, "", ""};
 }
 
-std::vector<DataSet> const &
+Value::DataSets const &
 STOWRSRequest
 ::get_data_sets() const
 {
-    return _data_sets;
+    return this->_data_sets;
 }
 
-std::vector<DataSet> &
+Value::DataSets &
 STOWRSRequest
 ::get_data_sets()
 {
@@ -384,74 +331,71 @@ STOWRSRequest
     HTTPRequest request;
     if(this->_representation == Representation::DICOM)
     {
-        auto const accumulator =
-            [](DataSet const & data_set)
+        auto const boundary = random_boundary();
+        std::string body;
+        OStringStream stream(body);
+        accumulate_parts(
+            this->get_data_sets().begin(), this->get_data_sets().end(),
+            [](std::shared_ptr<DataSet const> data_set)
             {
-                std::ostringstream stream(
-                    std::ios_base::out | std::ios_base::binary);
-                odil::Writer::write_file(
-                    data_set, stream, DataSet());
+                std::string buffer;
+                OStringStream stream(buffer);
+                Writer::write_file(data_set, stream);
+                stream.flush();
+
                 return Message(
                     {
                         {
                             "Content-Type",
-                            ItemWithParameters(
-                            "application/dicom",
-                            {})
+                            ItemWithParameters("application/dicom")
                         }
                     },
-                    stream.str()
+                    buffer
                 );
-            };
-        auto const boundary = random_boundary();
-        std::ostringstream body;
-        accumulate_parts(
-            this->get_data_sets().begin(), this->get_data_sets().end(),
-            accumulator, body, boundary);
-        request.set_body(body.str());
+            },
+            stream, boundary);
+        stream.flush();
+
+        request.set_body(body);
 
         request.set_header(
             "Content-Type",
             ItemWithParameters(
-                "multipart/related", {
-                            {"type", "application/dicom"},
-                            {"boundary", boundary}}));
+                "multipart/related",
+                {
+                    {"type", "application/dicom"}, {"boundary", boundary}
+                }));
     }
     else if(this->_representation == Representation::DICOM_JSON)
     {
-        std::vector<BulkData> bulk_data;
-
         // Copy the dataSets in order to let them unchanged
-        std::vector<odil::DataSet> copy = this->_data_sets;
-        for (auto & ds :copy)
+        Value::DataSets copy;
+        for(auto const & data_set: this->_data_sets)
+        {
+            copy.push_back(std::make_shared<DataSet>(*data_set));
+        }
+
+        std::vector<BulkData> bulk_data;
+        for(auto & ds: copy)
         {
             STOWRSRequest::_extract_bulk_data(ds, bulk_data);
         }
-        auto const accumulator_bulk_data =
-            [](BulkData const & bulk_data)
-            {
-                return Message(
-                    {
-                        { "Content-Type", bulk_data.type },
-                        { "Content-Location", bulk_data.location }
-                    },
-                { bulk_data.data.begin(), bulk_data.data.end() }
-                );
-            };
-        auto const transfer_syntax = this->_transfer_syntax;
-        int meta_data_count = 0;
-        // Here we use a vector only to keep the same behaviour for accumulate_parts
-        std::vector<Json::Value> json_vec;
+
         Json::Value json;
         json.resize(this->_data_sets.size());
-        for (auto const data_set : copy )
+        for(int i=0; i<copy.size(); ++i)
         {
-            json[meta_data_count++] = as_json(data_set);
+            json[i] = as_json(copy[i]);
         }
-        json_vec.push_back(json);
 
-        auto const accumulator_meta_data =
-            [transfer_syntax](Json::Value const & json_)
+        std::vector<Json::Value> const json_vector{{json}};
+        auto const boundary = random_boundary();
+        std::ostringstream body;
+
+        // Add data sets
+        accumulate_parts(
+            json_vector.begin(), json_vector.end(),
+            [this](Json::Value const & json)
             {
                 Json::FastWriter writer;
                 return Message(
@@ -459,19 +403,15 @@ STOWRSRequest
                         "Content-Type",
                         ItemWithParameters(
                             "application/dicom+json",
-                            {{"transfer-syntax", transfer_syntax}})
+                            {{"transfer-syntax", this->_transfer_syntax}})
                     }},
-                    writer.write(json_)
+                    writer.write(json)
                 );
-            };
-        auto const boundary = random_boundary();
-        std::ostringstream body;
-        // add here first the meta_data
-        accumulate_parts(
-            json_vec.begin(), json_vec.end(),
-            accumulator_meta_data, body, boundary);
+            },
+            body, boundary);
+
         // add then the bulk data
-        if (!bulk_data.empty())
+        if(!bulk_data.empty())
         {
             // Remove the last boundary of the message
             auto body_content = body.str();
@@ -482,7 +422,17 @@ STOWRSRequest
 
             accumulate_parts(
                 bulk_data.begin(), bulk_data.end(),
-                accumulator_bulk_data, body, boundary);
+                [](BulkData const & bulk_data)
+                {
+                    return Message(
+                        {
+                            { "Content-Type", bulk_data.type },
+                            { "Content-Location", bulk_data.location }
+                        },
+                        { bulk_data.data.begin(), bulk_data.data.end() }
+                    );
+                },
+                body, boundary);
         }
 
         request.set_body(body.str());
@@ -496,11 +446,15 @@ STOWRSRequest
     }
     else if(this->_representation == Representation::DICOM_XML)
     {
-        std::vector<BulkData> bulk_data;
-
         // Copy the dataSets in order to let them unchanged
-        std::vector<odil::DataSet> copy = this->_data_sets;
-        for (auto & ds :copy)
+        Value::DataSets copy;
+        for(auto const & data_set: this->_data_sets)
+        {
+            copy.push_back(std::make_shared<DataSet>(*data_set));
+        }
+
+        std::vector<BulkData> bulk_data;
+        for (auto & ds: copy)
         {
             STOWRSRequest::_extract_bulk_data(ds, bulk_data);
         }
@@ -517,18 +471,22 @@ STOWRSRequest
                 );
             };
 
-        auto const transfer_syntax = this->_transfer_syntax;
-        auto const accumulator_meta_data =
-            [transfer_syntax](DataSet const & data_set)
+        auto const boundary = random_boundary();
+        std::ostringstream body;
+
+        // Add the data sets
+        accumulate_parts(
+            copy.begin(), copy.end(),
+            [this](std::shared_ptr<DataSet const> data_set)
             {
                 auto const xml = as_xml(data_set);
                 std::ostringstream stream;
 
-#if BOOST_VERSION >= 105600
+    #if BOOST_VERSION >= 105600
                 typedef boost::property_tree::xml_writer_settings<std::string> SettingsType;
-#else
+    #else
                 typedef boost::property_tree::xml_writer_settings<char> SettingsType;
-#endif
+    #endif
 
                 boost::property_tree::write_xml(stream, xml, SettingsType());
 
@@ -537,18 +495,13 @@ STOWRSRequest
                         "Content-Type",
                         ItemWithParameters(
                             "application/dicom+xml",
-                            {{"transfer-syntax", transfer_syntax}})
+                            {{"transfer-syntax", this->_transfer_syntax}})
                     }},
                     stream.str()
                 );
-            };
+            },
+            body, boundary);
 
-        auto const boundary = random_boundary();
-        std::ostringstream body;
-        // add here first the meta_data
-        accumulate_parts(
-            copy.begin(), copy.end(),
-            accumulator_meta_data, body, boundary);
         // add then the bulk data
         if (!bulk_data.empty())
         {
@@ -561,7 +514,17 @@ STOWRSRequest
 
             accumulate_parts(
                 bulk_data.begin(), bulk_data.end(),
-                accumulator_bulk_data, body, boundary);
+                [](BulkData const & bulk_data)
+                {
+                    return Message(
+                        {
+                            { "Content-Type", bulk_data.type },
+                            { "Content-Location", bulk_data.location }
+                        },
+                    { bulk_data.data.begin(), bulk_data.data.end() }
+                    );
+                },
+                body, boundary);
         }
 
         request.set_body(body.str());
@@ -577,21 +540,24 @@ STOWRSRequest
     {
         throw Exception("Unknown type");
     }
+
     request.set_method("POST");
     request.set_target(this->_url);
     request.set_http_version("HTTP/1.0");
+
     return request;
 }
 
 void
 STOWRSRequest
-::_extract_bulk_data(DataSet &data_set, std::vector<BulkData> & bulk_data)
+::_extract_bulk_data(
+    std::shared_ptr<DataSet> data_set, std::vector<BulkData> & bulk_data)
 {
-    for (auto &it : data_set)
+    for(auto & it: *data_set)
     {
         auto & tag = it.first;
         auto & element = it.second;
-        if (data_set.is_binary(tag))
+        if(element.is_binary())
         {
             // 1. generate uuid
             boost::uuids::random_generator gen;
@@ -599,18 +565,16 @@ STOWRSRequest
             std::string uuid_string = boost::uuids::to_string(uuid);
 
             // 2. Get Transfer Syntax from dataSet
-            auto const default_transfer_syntax =
-                odil::registry::ExplicitVRLittleEndian;
             std::string const & transfer_syntax =
-                    data_set.get_transfer_syntax().empty()
-                        ?default_transfer_syntax
-                        :data_set.get_transfer_syntax();
+                    data_set->get_transfer_syntax().empty()
+                        ?registry::ExplicitVRLittleEndian
+                        :data_set->get_transfer_syntax();
 
             // 3. Create a new BulkData
             BulkData data;
             data.data = *element.as_binary().data();
             data.location = uuid_string;
-            if (tag == odil::registry::PixelData)
+            if(tag == registry::PixelData)
             {
                 data.type = STOWRSRequest::_media_type_from_transfer_syntax(transfer_syntax);
             }
@@ -623,14 +587,14 @@ STOWRSRequest
             bulk_data.push_back(data);
 
             // 5. Update the data_set giving in parameter
-            data_set.add(tag, {uuid_string}, odil::VR::UR);
+            data_set->add(tag, {uuid_string}, VR::UR);
         }
-        else if (data_set.is_data_set(tag))
+        else if (data_set->is_data_set(tag))
         {
             // Case of sequence with multiple sub-elements
-            for (auto sq : data_set.as_data_set(tag))
+            for(auto & item: element.as_data_set())
             {
-                STOWRSRequest::_extract_bulk_data(sq, bulk_data);
+                STOWRSRequest::_extract_bulk_data(item, bulk_data);
             }
         }
         else
@@ -642,50 +606,36 @@ STOWRSRequest
 
 void
 STOWRSRequest
-::_restore_data_set(DataSet &data_set, std::map<std::string, std::string>& uuid_bulk_raw)
+::_restore_data_set(std::shared_ptr<DataSet> data_set, BulkMap & bulk_map)
 {
-    for (auto & it : data_set)
+    for(auto & it: *data_set)
     {
         auto & tag = it.first;
         auto & element = it.second;
-        if (data_set.get_vr(tag) == odil::VR::UR)
+        if(element.vr == VR::UR)
         {
-            if (uuid_bulk_raw.find(element.as_string()[0]) !=
-                    uuid_bulk_raw.end())
+            auto const bulk_map_it = bulk_map.find(element.as_string()[0]);
+            if(bulk_map_it != bulk_map.end())
             {
-                auto const uuid = element.as_string()[0];
-                auto const bulk = uuid_bulk_raw.at(uuid);
-                std::stringstream stream(bulk);
-
-                auto const default_transfer_syntax =
-                    odil::registry::ExplicitVRLittleEndian;
                 std::string const & transfer_syntax =
-                        data_set.get_transfer_syntax().empty()
-                            ?default_transfer_syntax
-                            :data_set.get_transfer_syntax();
+                    data_set->get_transfer_syntax().empty()
+                    ?registry::ExplicitVRLittleEndian
+                    :data_set->get_transfer_syntax();
+                VRFinder vr_finder;
+                auto const vr = vr_finder(tag, data_set, transfer_syntax);
 
-                Reader reader(stream, transfer_syntax);
-                std::vector<uint8_t>  data;
-                for (auto const character : bulk)
-                {
-                    data.push_back(character);
-                }
-
-                // Update the data_set
-                odil::VRFinder vr_finder;
-                odil::VR vr = vr_finder(tag, data_set, transfer_syntax);
-                data_set.add(tag, odil::Value::Binary({data}), vr);
+                data_set->add(tag, Value::Binary({bulk_map_it->second}), vr);
             }
             else
             {
-                // Do nothing (some other UR but not concerned by the bulk data restoration)
+                // Do nothing: not a bulk data element
             }
         }
-        else if (data_set.is_data_set(tag))
+        else if(element.is_data_set())
         {
-            for (auto sq : data_set.as_data_set(tag))
+            for(auto & item: element.as_data_set())
             {
-                STOWRSRequest::_restore_data_set(sq, uuid_bulk_raw);
+                STOWRSRequest::_restore_data_set(item, bulk_map);
             }
         }
         else
