@@ -21,7 +21,7 @@ struct Fixture: public MessageFixtureBase<odil::message::CFindRequest>
             "CommandField", {odil::message::Message::Command::C_FIND_RQ});
         this->command_set->add("MessageID", {1234});
         this->command_set->add("AffectedSOPClassUID",
-            {odil::registry::PatientRootQueryRetrieveInformationModelFIND});
+            {odil::registry::PatientRootQueryRetrieveInformationModelFind});
         this->command_set->add(
             "Priority", {odil::message::Message::Priority::MEDIUM});
 
@@ -38,7 +38,7 @@ struct Fixture: public MessageFixtureBase<odil::message::CFindRequest>
         BOOST_CHECK_EQUAL(message.get_message_id(), 1234);
         BOOST_CHECK_EQUAL(
             message.get_affected_sop_class_uid(),
-            odil::registry::PatientRootQueryRetrieveInformationModelFIND);
+            odil::registry::PatientRootQueryRetrieveInformationModelFind);
         BOOST_CHECK(*message.get_data_set() == *this->query);
     }
 };
@@ -46,7 +46,7 @@ struct Fixture: public MessageFixtureBase<odil::message::CFindRequest>
 BOOST_FIXTURE_TEST_CASE(Constructor, Fixture)
 {
     odil::message::CFindRequest const message(
-        1234, odil::registry::PatientRootQueryRetrieveInformationModelFIND,
+        1234, odil::registry::PatientRootQueryRetrieveInformationModelFind,
         odil::message::Message::Priority::MEDIUM, this->query);
     this->check(message);
 }
