@@ -8,7 +8,7 @@ class TestRegistry(unittest.TestCase):
         self.assertEqual(tag.group, 0x0010)
         self.assertEqual(tag.element, 0x0020)
 
-    def test_public_dictionary(self):
+    def test_public_dictionary_tag(self):
         tag = odil.registry.PatientID
         self.assertTrue(tag in odil.registry.public_dictionary)
         entry = odil.registry.public_dictionary[tag]
@@ -16,6 +16,15 @@ class TestRegistry(unittest.TestCase):
         self.assertEqual(entry.keyword, "PatientID")
         self.assertEqual(entry.vr, "LO")
         self.assertEqual(entry.vm, "1")
+    
+    def test_public_dictionary_string(self):
+        string = "60xx0010"
+        self.assertTrue(string in odil.registry.public_dictionary)
+        entry = odil.registry.public_dictionary[string]
+        self.assertEqual(entry.name, "Overlay Rows")
+        self.assertEqual(entry.keyword, "OverlayRows")
+        self.assertEqual(entry.vr, "US")
+        self.assertEqual(entry.vm, "1")
 
     def test_uids_dictionary(self):
         uid = "1.2.840.10008.1.2.1"
